==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesUefiSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property secureBootEnabled Specifies whether secure boot should be enabled on the virtual machine.
 */
public data class VirtualMachinePropertiesUefiSettingsArgs(
    public val secureBootEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs.builder()
            .secureBootEnabled(secureBootEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachinePropertiesUefiSettingsArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesUefiSettingsArgsBuilder internal constructor() {
    private var secureBootEnabled: Output<Boolean>? = null

    /**
     * @param value Specifies whether secure boot should be enabled on the virtual machine.
     */
    @JvmName("rvxcaewosunchecl")
    public suspend fun secureBootEnabled(`value`: Output<Boolean>) {
        this.secureBootEnabled = value
    }

    /**
     * @param value Specifies whether secure boot should be enabled on the virtual machine.
     */
    @JvmName("rfowhrjwktdlysvo")
    public suspend fun secureBootEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secureBootEnabled = mapped
    }

    internal fun build(): VirtualMachinePropertiesUefiSettingsArgs =
        VirtualMachinePropertiesUefiSettingsArgs(
            secureBootEnabled = secureBootEnabled,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesUefiSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property secureBootEnabled Specifies whether secure boot should be enabled on the virtual machine.
 */
public data class VirtualMachinePropertiesUefiSettingsArgs(
    public val secureBootEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesUefiSettingsArgs.builder()
            .secureBootEnabled(secureBootEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachinePropertiesUefiSettingsArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesUefiSettingsArgsBuilder internal constructor() {
    private var secureBootEnabled: Output<Boolean>? = null

    /**
     * @param value Specifies whether secure boot should be enabled on the virtual machine.
     */
    @JvmName("knauejjbofcvddqh")
    public suspend fun secureBootEnabled(`value`: Output<Boolean>) {
        this.secureBootEnabled = value
    }

    /**
     * @param value Specifies whether secure boot should be enabled on the virtual machine.
     */
    @JvmName("exccivtnnpubjnkc")
    public suspend fun secureBootEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secureBootEnabled = mapped
    }

    internal fun build(): VirtualMachinePropertiesUefiSettingsArgs =
        VirtualMachinePropertiesUefiSettingsArgs(
            secureBootEnabled = secureBootEnabled,
        )
}
